#pragma once
#include <tec/TecFrame.h>
#include <list>

enum class ValueType { Int, Float };
enum class Direction { Read, ReadWrite };
struct ParameterDescriptor {
  /// Base name of the process varable (aka DOOCS property), without ".RD", ".RW" suffix etc.
  std::string pvName;

  /// TecParameter identifier for the hardware protocol
  TecFrame::TecParameter value;

  /// Value type
  ValueType valueType;

  /// Direction
  Direction direction;

  /// Engineering unit
  std::string unit;

  /// Parameter desccription
  std::string description;

  /// Base name of the process variable for the read-group command
  std::string readGroup;

  /// Base name of the process variable for the write-group command, empty for Direction::Read
  std::string writeGroup;

  /// Base name of the process variable for the write-to-flash-group command, empty for Direction::Read
  std::string writeToFlashGroup;

  /// Base name of the proess variable for the set-from-readback-group command, empty for Direction::Read
  std::string setFromReadbackGroup;
};

static std::list<ParameterDescriptor> descriptors{
    {"mon_ch1_SinkTemp", TecFrame::TecParameter::MonSinkTemperature, ValueType::Float, Direction::Read, "unit", "description",
        "readCh1Group1", "", "", ""},
    
    {"mon_serialNumber", TecFrame::TecParameter::MonSerialNumber, ValueType::Int, Direction::Read, "unit", "description",
        "readGroup1", "", "", ""},
                
    {"ctrl_ch1_fanControlEnable", TecFrame::TecParameter::ExpFanControlEnable, ValueType::Int, Direction::ReadWrite, "unit", "description",
        "readCh1WriteGroup7", "writeCh1Group7", "writeToFlashCh1Group7", "setRbCh1Group7"},

    {"ctrl_ch1_targetObjectTemp", TecFrame::TecParameter::TemTargetObjectTemp, ValueType::Float, Direction::ReadWrite, "unit", "description",
        "readCh1WriteGroup1", "writeCh1Group1", "writeToFlashCh1Group1", "setRbCh1Group1"}
};
